summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
index cb0d6e4c..3806194e 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
@@ -37,13 +37,14 @@ class KDockButton_Private;
class KMDI_EXPORT KMdiDockContainer: public TQWidget, public KDockContainer
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMdiDockContainer( TQWidget *parent, TQWidget *win, int position, int flags );
+ KMdiDockContainer( TQWidget *tqparent, TQWidget *win, int position, int flags );
virtual ~KMdiDockContainer();
- /** Get the KDockWidget that is our parent */
- KDockWidget *parentDockWidget();
+ /** Get the KDockWidget that is our tqparent */
+ KDockWidget *tqparentDockWidget();
/**
* Add a widget to this container
@@ -90,28 +91,28 @@ public:
/**
* Save the config using a KConfig object
*
* The combination of the group_or_prefix variable and the parent
* dockwidget's name will be the group the configuration is saved in
* \param group_or_prefix the prefix to append to the parent dockwidget's name
*/
virtual void save( KConfig *, const TQString& group_or_prefix );
/**
* Load the config using a KConfig object
*
* The combination of the group_or_prefix variable and the parent
* dockwidget's name will be the group the configuration is loaded from
* \param group_or_prefix the prefix to append to the parent dockwidget's name
*/
virtual void load( KConfig *, const TQString& group_or_prefix );
/**
- * Save the config to a QDomElement
+ * Save the config to a TQDomElement
*/
virtual void save( TQDomElement& );
/**
- * Load the config from a QDomElement
+ * Load the config from a TQDomElement
*/
virtual void load( TQDomElement& );
@@ -164,4 +165,4 @@ signals:
#endif
-// kate: space-indent off; tab-width 4; replace-tabs off; indent-mode csands;
+// kate: space-indent off; tab-width 4; tqreplace-tabs off; indent-mode csands;
@@ -90,28 +91,28 @@ public:
* Save the config using a KConfig object
*
- * The combination of the group_or_prefix variable and the parent
+ * The combination of the group_or_prefix variable and the tqparent
* dockwidget's name will be the group the configuration is saved in
@@ -90,28 +91,28 @@ public:
* dockwidget's name will be the group the configuration is saved in
- * \param group_or_prefix the prefix to append to the parent dockwidget's name
+ * \param group_or_prefix the prefix to append to the tqparent dockwidget's name
*/
virtual void save( KConfig *, const TQString& group_or_prefix );
@@ -90,28 +91,28 @@ public:
* Load the config using a KConfig object
*
- * The combination of the group_or_prefix variable and the parent
+ * The combination of the group_or_prefix variable and the tqparent
* dockwidget's name will be the group the configuration is loaded from
@@ -90,28 +91,28 @@ public:
* dockwidget's name will be the group the configuration is loaded from
- * \param group_or_prefix the prefix to append to the parent dockwidget's name
+ * \param group_or_prefix the prefix to append to the tqparent dockwidget's name
*/
virtual void load( KConfig *, const TQString& group_or_prefix );